# pyrx

A Python extension for getting RandomX hashes.

## Installation

```
pip install git+https://github.com/jtgrassie/pyrx
```

## Usage

See [tests/test.py](./tests/test.py).

## Supporting the project

XMR donations to:

```
451ytzQg1vUVkuAW73VsQ72G96FUjASi4WNQse3v8ALfjiR5vLzGQ2hMUdYhG38Fi15eJ5FJ1ZL4EV1SFVi228muGX4f3SV
```

![QR code](./qr-small.png)

would be very much appreciated.

## License

Please see the [LICENSE](./LICENSE) file.

[//]: # ( vim: set tw=80: )
